=============
Django-Twilio2
=============

Integrate Twilio into your Django apps with ease.

This is a fork of the original django-twilio. The original one was not recieving updates on pypi.
The original can be found here:
https://github.com/rdegges/django-twilio

Meta
----

* Maintainer: Kyle Mulka
* Email: repalviglator@yahoo.com

Twilio makes it easy to send & receive SMS messages, and create & manage voice calls through software.

Django-twilio2 makes it easy to use Twilio in your Django projects.

Documentation
-------------

The documentation is hosted at ReadTheDocs. You can check out the docs
here - http://django-twilio.rtfd.org/
